#
# spec file for package mhash
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mhash
Version:        0.9.9.9
Release:        31.6
Summary:        A Library for Working with Strong Hashes
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            http://mhash.sourceforge.net/
Source:         https://sourceforge.net/projects/%{name}/files/%{name}/%{version}/%{name}-%{version}.tar.bz2
Patch0:         %{name}-%{version}-shared.diff
# PATCH-FIX-UPSTREAM fix-for-upstream-sources.patch sourceforge#2908478
Patch1:         mhash_remove_premature_free.patch
Patch2:         mhash-0.9.9.9-fix-snefru-segfault.patch
Patch3:         mhash-0.9.9.9-fix-mem-leak.patch
Patch4:         mhash-0.9.9.9-fix-whirlpool-segfault.patch
Patch5:         mhash-0.9.9-no-free-before-use.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The mhash library provides an easy way to access strong hashes, such as
MD5, SHA1, and other algorithms.

%package -n lib%{name}2
Summary:        A Library for Working with Strong Hashes
Group:          System/Libraries
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n lib%{name}2
The mhash library provides an easy way to access strong hashes, such as
MD5, SHA1, and other algorithms.

%package devel
Summary:        Header Files for mhash Library
Group:          Development/Libraries/C and C++
Requires:       lib%{name}2 = %{version}
Provides:       %{name}:%{_includedir}/%{name}.h

%description devel
The mhash library provides an easy way to access strong hashes such as
MD5, SHA1, and other algorithms.

%prep
%setup -q
%patch0
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1

%build
autoreconf --force --install
%configure \
	--with-pic \
	--disable-static

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
# useless .la file 
rm %{buildroot}%{_libdir}/lib%{name}.la

%check
make %{?_smp_mflags} check

%post -n lib%{name}2 -p /sbin/ldconfig

%postun -n lib%{name}2 -p /sbin/ldconfig

%files -n lib%{name}2
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README THANKS TODO
%{_libdir}/libmhash.so.*

%files devel
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README THANKS TODO
%doc doc/skid2-authentication doc/example.c
%doc %{_mandir}/man?/*
%{_includedir}/*
%{_libdir}/libmhash.so

%changelog
* Fri Apr 29 2022 Marcus Meissner <meissner@suse.com>
- switched source url to https
* Mon Jan 20 2020 ro@suse.de
- add a few patches from the fedora package to tackle
  a crash in the testsuite on 32bit
  - add patch mhash-0.9.9.9-fix-snefru-segfault.patch
  - add patch mhash-0.9.9.9-fix-whirlpool-segfault.patch
  - add patch mhash-0.9.9.9-fix-mem-leak.patch
  - add patch mhash-0.9.9-no-free-before-use.patch
* Thu Feb 26 2015 mpluskal@suse.com
- Move part of documentation to devel package
* Thu Feb 26 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Refresh dependencies
- Move libraries to libmhash2 to comply with shlip policies
- Use url for source
* Sat Jan 12 2013 coolo@suse.com
- remove suse_update_config
* Wed Nov 16 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Mon Jan 18 2010 coolo@novell.com
- take patch from sourceforge.net tracker to fix test suite
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Fri Mar  6 2009 crrodriguez@suse.de
- remove static libraries
- run make check
* Mon Jan 19 2009 prusnak@suse.cz
- updated to 0.9.9.9
  * Added patch for sigbus error on unaligned data,
    when doing rapid copies
* Sun Aug 12 2007 crrodriguez@suse.de
- missing glibc-devel dependency on -devel package
* Thu Apr  5 2007 prusnak@suse.cz
- update do 0.9.9
  * fixed sigbus error on unaligned data
  * fixed Haval endian problem
  * polished some memory leaks
  * fixed symbol clashes
* Wed Jan  3 2007 prusnak@suse.cz
- update to 0.9.7.1
  * better handling of endian issues
  * eliminated redundant code
- drop obsolete patches:
  * mhash-0.9.4a-comparison.diff
  * mhash-0.9.4a-include.diff
  * mhash-0.9.4a-uninitialized.diff
  * mhash-0.9.4a-stdfns.diff
* Tue Apr 18 2006 ro@suse.de
- use stdfns.c from 0.9.6 to fix bigendian platforms
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 mjancar@suse.cz
- fix missing = in comparison (#145503)
* Sun Jan 15 2006 aj@suse.de
- Fix warnings about uninitialized variables.
- Package mutils/mincludes.h since it's used by <mhash.h>.
* Wed Jan 11 2006 mjancar@suse.cz
- update to 0.9.4a
* Sun Dec 11 2005 ro@suse.de
- install mhash_config.h since include files are pretty broken
  by using autoconf-HAVE_.. values globally visible
* Fri Dec  9 2005 mjancar@suse.cz
- update to 0.9.3
* Thu Sep 22 2005 ro@suse.de
- fix implicit declarations
* Mon Feb  7 2005 mjancar@suse.cz
- update to 0.9.2
* Fri Aug  6 2004 mjancar@suse.cz
- update to 0.9.1
* Wed Jan 21 2004 ro@suse.de
- fix build (remove commented line from configure.in)
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Thu Jul 31 2003 mjancar@suse.cz
- use %%run_ldconfig
* Wed Jun 11 2003 mjancar@suse.cz
- enable static library
* Tue Jun 10 2003 mjancar@suse.cz
- update to 0.8.18
* Mon Feb 17 2003 vbobek@suse.cz
- updated to version 0.8.17
  * Corrected the HEX key mode. Refuses to convert hex strings longer
  than the given key size.
  * Corrected some memory leaks in keygen_s2k.
  * Corrected wrong use of sizeof in hmac_test.
* Fri Sep  6 2002 jg@suse.de
- using -fPIC to compile libmhash
* Fri Aug 30 2002 pmladek@suse.cz
- fixed dependency of the devel subpackage on the main package (used %%version)
- fixed file list of the devel subpackage (removed duplicities with the main
  package)
* Thu Aug 15 2002 mge@suse.de
-  updated to 0.8.16
* Fri Jan 18 2002 pmladek@suse.cz
- upadted to version 0.8.13:
  * added ADLER32 algorithm
  * added SHA-256 from libnettle
  * some new functions
  * some bug fixes
- used libtoolize --force, aclocal, autoconf
- fixed documetation
* Fri Jan 11 2002 pmladek@suse.cz
- devel package created
- used macro %%{_libdir} to fix for lib64
* Thu May 24 2001 pmladek@suse.cz
- fixed include files on ia64
* Tue Mar 27 2001 pmladek@suse.cz
- new package
- bziped sources
